@@ -1,6 +1,6 @@
 package Net::DNS::RR::KEY;
 
-# $Id: KEY.pm,v 1.4 2002/06/17 14:36:57 olaf Exp $
+# $Id: KEY.pm,v 1.6 2002/08/14 13:44:53 olaf Exp $
 
 use strict;
 use vars qw(@ISA $VERSION);
@@ -10,7 +10,7 @@ use MIME::Base64;
 use Carp;
 
 @ISA = qw(Net::DNS::RR);
-$VERSION = do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf "%d."."%03d"x$#r,@r };
+$VERSION = do { my @r=(q$Revision: 1.6 $=~/\d+/g); sprintf "%d."."%03d"x$#r,@r };
 sub new {
     my ($class, $self, $data, $offset) = @_;
     if ($self->{"rdlength"} > 0) {
@@ -42,9 +42,9 @@ sub new_from_string {
 	if ($string) {
 		$string =~ tr/()//d;
 		$string =~ s/;.*$//mg;
-		my ($flags, $protocol, $algorithm) = 
-		    $string =~ /^\s*(\S+)\s+(\S+)\s+(\S+)/;
-		my $key=$';       # everything after last match...
+		$string =~ s/\n//mg;
+		my ($flags, $protocol, $algorithm,$key) = 
+		    $string =~ /^\s*(\S+)\s+(\S+)\s+(\S+)\s+(.*)/;
 		$key =~ s/\s*//g;
 		$self->{"flags"}=$flags;
 		$self->{"algorithm"}=$algorithm;
@@ -142,6 +142,16 @@ sub setkeytag
 
 
 
+sub privatekeyname {
+    my $self=shift;
+    return sprintf("K%s.+%03d+%05d.private",
+		   $self->name,
+		   $self->{"algorithm"},
+		   $self->keytag);
+    
+}
+
+
 
 1;
 
@@ -208,7 +218,17 @@ Returns the key binary material
 
 Returns the key tag of the key. (RFC2535 4.1.6)
 
+=head2 privatekeyname
 
+    $privatekeyname=$rr->privatekeyname
+
+Returns the name of the privatekey as it would be generated by
+the BIND dnssec-keygen program. The format of that name being
+K\<fqdn\>+\<algorithm\>+\<keyid\>.private
+
+
+
+    
 
 =head1 COPYRIGHT
 
