@@ -1,6 +1,6 @@
 # perldoc SIG.pm for documentation.
 # Specs: RFC 2535 section 4
-# $Id: SIG.pm,v 1.11 2003/01/08 08:13:11 olaf Exp $
+# $Id: SIG.pm,v 1.13 2003/09/01 15:59:01 olaf Exp $
 
 package Net::DNS::RR::SIG;
 
@@ -11,12 +11,12 @@ use Carp;
 
 use Crypt::OpenSSL::DSA;
 use Crypt::OpenSSL::RSA;
-
-use Net::DNS::RR::SIG::Private;
+use Crypt::OpenSSL::Bignum;
+use Net::DNS::SEC::Private;
 
 use File::Basename;
 use MIME::Base64;
-use Math::BigInt;    
+use Math::BigInt;
 use Time::Local;
 use Digest::SHA1 qw (sha1);
 
@@ -33,7 +33,7 @@ use Digest::SHA1 qw (sha1);
 
 require Exporter;
 
-$VERSION = do { my @r=(q$Revision: 1.11 $=~/\d+/g); sprintf "%d."."%03d"x$#r,@r };
+$VERSION = do { my @r=(q$Revision: 1.13 $=~/\d+/g); sprintf "%d."."%03d"x$#r,@r };
 @ISA = qw (
 	   Exporter
 	 Net::DNS::RR
@@ -46,7 +46,8 @@ $VERSION = do { my @r=(q$Revision: 1.11 $=~/\d+/g); sprintf "%d."."%03d"x$#r,@r
 use strict;
 my $debug=0;
 my $crypt_open_ssl=1;
-
+my $__DeprecationWarningVerifyShown=0;
+my $__DeprecationWarningCreateShown=0;
 
 
 
@@ -219,7 +220,9 @@ sub rr_rdata {
 		    $self->{"algorithm"} == 5)
 		{  #RSA
 
-		    my $rsa_priv=Crypt::OpenSSL::RSA->new_private_key($self->{"private_key"});
+
+#		  my $rsa_priv=Crypt::OpenSSL::RSA->new_private_key($self->{"private_key"});
+		  my $rsa_priv=$self->{"private_key"};
 		    eval {
 			$rsa_priv->use_pkcs1_oaep_padding;
 			if ($self->{"algorithm"} == 1) {
@@ -307,13 +310,13 @@ sub create {
     my $Private;
 
 
-    if (UNIVERSAL::isa($priv_key,"Net::DNS::RR::SIG::Private")){
+    if (UNIVERSAL::isa($priv_key,"Net::DNS::SEC::Private")){
 	$Private=$priv_key;
     }else{
-	$Private=Net::DNS::RR::SIG::Private->new($priv_key);
+	$Private=Net::DNS::SEC::Private->new($priv_key);
     }
 
-    die "Create did not manage obtain a Net::DNS::RR::SIG::Private object "unless (UNIVERSAL::isa($Private,"Net::DNS::RR::SIG::Private"));
+    die "Create did not manage obtain a Net::DNS::SEC::Private object "unless (UNIVERSAL::isa($Private,"Net::DNS::SEC::Private"));
 
     $self->{"algorithm"}=$Private->algorithm;
      $self->{"keytag"}=$Private->keytag;
@@ -352,6 +355,9 @@ sub create {
     if ($sigzero){
 	$self->{"typecovered"}="SIGZERO";
     }else{
+	print "Note: the SIG RR has been deprecated for use other than SIG0; use the RRSIG instead\n"		  if !$__DeprecationWarningCreateShown ;
+		$__DeprecationWarningCreateShown=1;
+
 	$self->{"typecovered"}=$datarrset->[0]->type;  #Sanity checks elsewhere
     }
 
@@ -456,10 +462,6 @@ sub create {
     my $sigdata=$self->_CreateSigData($datarrset);
 
 
-    # We will now create a Crypt::OpenSSL::RSA object. It is needed
-    # for signing.  
-    # The Crypt::OpenSSL::RSA class uses ANS1 DER encoding to read private
-    # and public keys.
 
 
     my $signature;
@@ -471,7 +473,8 @@ sub create {
 	    die "Private key mismatch, not RSAMD5 or RSASHA.";
 	    
 	}
-	my $rsa_priv = Crypt::OpenSSL::RSA->new_private_key($Private->privatekey);
+#	my $rsa_priv = Crypt::OpenSSL::RSA->new_private_key($Private->privatekey);
+	my $rsa_priv = $Private->privatekey;
 	$self->{"private_key"}=$Private->privatekey;
 	eval {
 	    $rsa_priv->use_pkcs1_oaep_padding;
@@ -560,9 +563,12 @@ sub verify {
     $sigzero_verify=1 unless (ref($dataref));
     if (! $sigzero_verify ){
 	if (ref($dataref) eq "ARRAY"){
-
 	    if (ref($dataref->[0]) and $dataref->[0]->isa('Net::DNS::RR')){
 		$rrarray_verify=1;
+
+	print "Note: the SIG RR has been deprecated for use other than SIG0; use the RRSIG instead\n"		  
+		  if !$__DeprecationWarningVerifyShown ;
+		$__DeprecationWarningVerifyShown=1;
 	    }else{
 		die "Trying to verify an array of ".  ref( $dataref->[0]) ."\n";
 	    }
@@ -570,7 +576,6 @@ sub verify {
 	    $packet_verify=1 if ((ref($dataref)) and $dataref->isa("Net::DNS::Packet"));
 	    die "Trying to verify a packet while signature is not of SIG0 type"
 		if ($self->{"typecovered"} ne "SIGZERO");
-	    
 	}else{
 	    die "Do not know what kind of data this is" . ref( $dataref) . ")\n";
 	}
@@ -814,9 +819,6 @@ sub _verifyRSA {
 	    if $debug;
     # RSA RFC2535
     # 
-    # Again we need to put the public key into ANS1 DER encoding so that
-    # the RSA public key can read it.
-
     
     my $explength;
     my $exponent;
@@ -858,39 +860,14 @@ sub _verifyRSA {
 	}
     }
     
-    
-    #   We have the modulus and the exponent we now need to put this
-    #   in an X509 encoded public key to use
-    #   Crypt::OpenSSL::RSA::load_public_key 
-    
-    
-    #   Load a public key in from an X509 encoded string. The string
-    #   should include the -----BEGIN...----- and -----END...-----
-    #   lines. The padding is set to PKCS1_OAEP, but can be changed
-    #   with set_padding.
-    
-    #   the modulus is a multiprecicion unsigned integer.  
-    #   The modulus in the RSA secuence is an integer as well.
-    
-    # The modulus is an unsigned integer. The ANS.1 DER encoding is two complements form.
-    # If the first bit of $modulus is 1 we have to append a 0 octed.
 
+    my $bn_modulus=Crypt::OpenSSL::Bignum->new_from_bin($modulus);
+    my $bn_exponent=Crypt::OpenSSL::Bignum->new_from_bin($exponent);
 
-    $modulus=Net::DNS::RR::SIG::Private::ANS1_integer($modulus);
-    $exponent=Net::DNS::RR::SIG::Private::ANS1_integer($exponent);
-    
-    # Same for the exponent.
-    
-    my $sequence=Net::DNS::RR::SIG::Private::ANS1_sequence($modulus . $exponent);
+  
 
-    
-    $RSAPublicKey="-----BEGIN RSA PUBLIC KEY-----\n".
-	encode_base64($sequence) .
-	    "-----END RSA PUBLIC KEY-----\n";
-    
-    
+    my $rsa_pub = Crypt::OpenSSL::RSA->new_key_from_parameters($bn_modulus,$bn_exponent);
 
-    my $rsa_pub = Crypt::OpenSSL::RSA->new_public_key($RSAPublicKey);
 
     die "Could not load public key" unless $rsa_pub;
     $rsa_pub->use_pkcs1_oaep_padding;
@@ -1110,6 +1087,13 @@ C<use Net::DNS::RR>;
 =head1 DESCRIPTION
 
 
+IMPORTANT: For any other use than SIG0 signatures the SIG RR has been
+depricated. Use the DNSSIG instead.
+
+All functionality remains present although a warning will be printed
+at first usage of the verify and create methods.
+
+
 Class for DNS Address (SIG) resource records. In addition to the
 regular methods in the Net::DNS::RR the Class contains a method to
 sign RRsets using private keys (create). And a class for verifying
@@ -1120,6 +1104,7 @@ The SIG RR is an implementation of RFC 2535 and RFC 2931.
 
 
 
+
 =head1 METHODS
 
 =head2 create
@@ -1163,7 +1148,6 @@ for other signatures (sigex=sigin+sigval).  If sigval is specified
 then sigex is ignored. The default for sigval is 5 minutes for SIG0s
 and 30 days other types of signatures.
 
-
 Note that for SIG0 signatures the default sigin is calculated at the
 moment the object is created, not at the moment that the packet is put
 on the wire (with ....). So do not leave the object hanging around for
@@ -1283,7 +1267,7 @@ the proper handling of times...
 Andy Vaskys (Network Associates Laboratories) supplied the code for
 handling RSA with SHA1 (Algorithm 5).
 
-Chris Reinardt for maintianing Net::DNS.  
+Chris Reinardt for maintianing Net::DNS.
 
 T.J. Mather, <tjmather@tjmather.com>, the Crypt::OpenSSL::DSA
 maintainer, for his quick responses to bug report and feature
